@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2014 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -95,6 +95,32 @@ const DecoderProperties DecoderFFmpegFactory::properties() const
     filters = settings.value("FFMPEG/filters", filters).toStringList();
 
     //removed unsupported filters
+#if (LIBAVCODEC_VERSION_INT >= ((55<<16)+(34<<8)+0)) //libav 10
+    if(!avcodec_find_decoder(AV_CODEC_ID_WMAV1))
+        filters.removeAll("*.wma");
+    if(!avcodec_find_decoder(AV_CODEC_ID_APE))
+        filters.removeAll("*.ape");
+    if(!avcodec_find_decoder(AV_CODEC_ID_TTA))
+        filters.removeAll("*.tta");
+    if(!avcodec_find_decoder(AV_CODEC_ID_AAC))
+        filters.removeAll("*.aac");
+    if(!avcodec_find_decoder(AV_CODEC_ID_MP3))
+        filters.removeAll("*.mp3");
+    if(!avcodec_find_decoder(AV_CODEC_ID_AAC) && !avcodec_find_decoder(AV_CODEC_ID_ALAC))
+        filters.removeAll("*.m4a");
+    if(!avcodec_find_decoder(AV_CODEC_ID_RA_288))
+        filters.removeAll("*.ra");
+    if(!avcodec_find_decoder(AV_CODEC_ID_SHORTEN))
+        filters.removeAll("*.shn");
+    if(!avcodec_find_decoder(AV_CODEC_ID_EAC3))
+        filters.removeAll("*.ac3");
+    if(!avcodec_find_decoder(AV_CODEC_ID_DTS))
+        filters.removeAll("*.dts");
+    if(!avcodec_find_decoder(AV_CODEC_ID_TRUEHD))
+        filters.removeAll("*.mka");
+    if(!avcodec_find_decoder(AV_CODEC_ID_TWINVQ))
+        filters.removeAll("*.vqf");
+#else
     if(!avcodec_find_decoder(CODEC_ID_WMAV1))
         filters.removeAll("*.wma");
     if(!avcodec_find_decoder(CODEC_ID_APE))
@@ -119,6 +145,7 @@ const DecoderProperties DecoderFFmpegFactory::properties() const
         filters.removeAll("*.mka");
     if(!avcodec_find_decoder(CODEC_ID_TWINVQ))
         filters.removeAll("*.vqf");
+#endif
 
 
     DecoderProperties properties;
