@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -224,7 +224,7 @@ void DecoderMADFactory::showAbout(QWidget *parent)
                         .arg(MAD_VERSION_MINOR)
                         .arg(MAD_VERSION_PATCH).arg(MAD_VERSION_EXTRA)+"\n"+
                         tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>")+"\n"+
-                        tr("Source code based on mq3 progect")
+                        tr("Source code based on mq3 and madplay projects")
                        );
 }
 
