@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,18 +15,18 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 
 #include <QObject>
 #include <QIODevice>
 #include <QFile>
+#include <QRegExp>
 #include <math.h>
 #include <stdint.h>
 #include <qmmp/buffer.h>
 #include <qmmp/output.h>
-#include <qmmp/recycler.h>
 #include "decoder_wavpack.h"
 #include "cueparser.h"
 
@@ -67,12 +67,15 @@ bool DecoderWavPack::initialize()
     char err [80];
     if (m_path.startsWith("wvpack://")) //embeded cue track
     {
-        QString p = QUrl(m_path).path();
-        p.replace(QString(QUrl::toPercentEncoding("#")), "#");
-        p.replace(QString(QUrl::toPercentEncoding("?")), "?");
-        p.replace(QString(QUrl::toPercentEncoding("%")), "%");
-        p.replace(QString(QUrl::toPercentEncoding(":")), ":");
-        m_context = WavpackOpenFileInput (p.toLocal8Bit(), err, OPEN_WVC | OPEN_TAGS, 0);
+        QString p = m_path;
+        p.remove("wvpack://");
+        p.remove(QRegExp("#\\d+$"));
+        m_context = WavpackOpenFileInput (p.toLocal8Bit().constData(), err, OPEN_WVC | OPEN_TAGS, 0);
+        if (!m_context)
+        {
+            qWarning("DecoderWavPack: error: %s", err);
+            return false;
+        }
         int cue_len = WavpackGetTagItem (m_context, "cuesheet", NULL, 0);
         char *value;
         if (cue_len)
@@ -89,7 +92,7 @@ bool DecoderWavPack::initialize()
             m_path = p;
             //send metadata
             QMap<Qmmp::MetaData, QString> metaData = m_parser->info(m_track)->metaData();
-            StateHandler::instance()->dispatch(metaData);
+            addMetaData(metaData);
         }
     }
     else
@@ -127,6 +130,7 @@ bool DecoderWavPack::initialize()
         length_in_bytes = audioParameters().sampleRate() *
                           audioParameters().channels() *
                           audioParameters().sampleSize() * m_length/1000;
+        setReplayGainInfo(m_parser->replayGain(m_track));
         seek(0);
     }
     m_totalBytes = 0;
@@ -240,7 +244,8 @@ void DecoderWavPack::next()
         length_in_bytes = audioParameters().sampleRate() *
                           audioParameters().channels() *
                           audioParameters().sampleSize() * m_length/1000;
-        StateHandler::instance()->dispatch(m_parser->info(m_track)->metaData());
+        addMetaData(m_parser->info(m_track)->metaData());
+        setReplayGainInfo(m_parser->replayGain(m_track));
         m_totalBytes = 0;
     }
 }
